# SPDX-License-Identifier: MIT
# Copyright (C) 2022 Max Bachmann
from __future__ import annotations

from rapidfuzz._utils import fallback_import as _fallback_import

_mod = "rapidfuzz.distance.metrics"
distance = _fallback_import(_mod, "lcs_seq_distance")
similarity = _fallback_import(_mod, "lcs_seq_similarity")
normalized_distance = _fallback_import(_mod, "lcs_seq_normalized_distance")
normalized_similarity = _fallback_import(_mod, "lcs_seq_normalized_similarity")
editops = _fallback_import(_mod, "lcs_seq_editops")
opcodes = _fallback_import(_mod, "lcs_seq_opcodes")



# SPDX-License-Identifier: MIT
# Copyright (C) 2022 Max Bachmann
"""
The Levenshtein (edit) distance is a string metric to measure the
difference between two strings/sequences s1 and s2.
It's defined as the minimum number of insertions, deletions or
substitutions required to transform s1 into s2.
"""

from __future__ import annotations

from typing import Callable, Hashable, Sequence

from rapidfuzz.distance import Editops, Opcodes

def distance(
    s1: Sequence[Hashable],
    s2: Sequence[Hashable],
    *,
    weights: tuple[int, int, int] | None = (1, 1, 1),
    processor: Callable[..., Sequence[Hashable]] | None = None,
    score_cutoff: int | None = None,
    score_hint: int | None = None,
) -> int: ...
def normalized_distance(
    s1: Sequence[Hashable],
    s2: Sequence[Hashable],
    *,
    weights: tuple[int, int, int] | None = (1, 1, 1),
    processor: Callable[..., Sequence[Hashable]] | None = None,
    score_cutoff: float | None = 0,
    score_hint: float | None = 0,
) -> float: ...
def similarity(
    s1: Sequence[Hashable],
    s2: Sequence[Hashable],
    *,
    weights: tuple[int, int, int] | None = (1, 1, 1),
    processor: Callable[..., Sequence[Hashable]] | None = None,
    score_cutoff: int | None = None,
    score_hint: int | None = None,
) -> int: ...
def normalized_similarity(
    s1: Sequence[Hashable],
    s2: Sequence[Hashable],
    *,
    weights: tuple[int, int, int] | None = (1, 1, 1),
    processor: Callable[..., Sequence[Hashable]] | None = None,
    score_cutoff: float | None = 0,
    score_hint: float | None = 0,
) -> float: ...
def editops(
    s1: Sequence[Hashable],
    s2: Sequence[Hashable],
    *,
    processor: Callable[..., Sequence[Hashable]] | None = None,
    score_hint: int | None = None,
) -> Editops: ...
def opcodes(
    s1: Sequence[Hashable],
    s2: Sequence[Hashable],
    *,
    processor: Callable[..., Sequence[Hashable]] | None = None,
    score_hint: int | None = None,
) -> Opcodes: ...



# Pyinstaller hook to successfully freeze: https://pyinstaller.readthedocs.io/en/stable/hooks.html
from __future__ import annotations

hiddenimports = [
    "array",
    "rapidfuzz.fuzz_py",
    "rapidfuzz.fuzz_cpp",
    "rapidfuzz.utils_py",
    "rapidfuzz.utils_cpp",
    "rapidfuzz.process_py",
    "rapidfuzz.process_cpp",
    # distances
    "rapidfuzz.distance._initialize_py",
    "rapidfuzz.distance._initialize_cpp",
    "rapidfuzz.distance.metrics_cpp",
    "rapidfuzz.distance.metrics_py",
]



# SPDX-License-Identifier: MIT
# Copyright (C) 2022 Max Bachmann
from __future__ import annotations

from rapidfuzz._utils import fallback_import as _fallback_import

_mod = "rapidfuzz.distance.metrics"
distance = _fallback_import(_mod, "jaro_distance")
similarity = _fallback_import(_mod, "jaro_similarity")
normalized_distance = _fallback_import(_mod, "jaro_normalized_distance")
normalized_similarity = _fallback_import(_mod, "jaro_normalized_similarity")



from __future__ import annotations

from rapidfuzz._utils import fallback_import as _fallback_import

_mod = "rapidfuzz.distance._initialize"
Editop = _fallback_import(_mod, "Editop")
Editops = _fallback_import(_mod, "Editops")
Opcode = _fallback_import(_mod, "Opcode")
Opcodes = _fallback_import(_mod, "Opcodes")
ScoreAlignment = _fallback_import(_mod, "ScoreAlignment")
MatchingBlock = _fallback_import(_mod, "MatchingBlock")

__all__ = [
    "Editop",
    "Editops",
    "Opcode",
    "Opcodes",
    "ScoreAlignment",
    "MatchingBlock",
]
